import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { DmsBillsInspectInstanceVO, DmsBillsInspectInstanceForm, DmsBillsInspectInstanceQuery } from '@/api/dms/dmsBillsInspectInstance/types';

/**
 * 查询点巡检工单列表
 * @param query
 * @returns {*}
 */

export const listDmsBillsInspectInstance = (query?: DmsBillsInspectInstanceQuery): AxiosPromise<DmsBillsInspectInstanceVO[]> => {
  return request({
    url: '/dms/dmsBillsInspectInstance/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询点巡检工单详细
 * @param inspectInstanceId
 */
export const getDmsBillsInspectInstance = (inspectInstanceId: string | number): AxiosPromise<DmsBillsInspectInstanceVO> => {
  return request({
    url: '/dms/dmsBillsInspectInstance/' + inspectInstanceId,
    method: 'get'
  });
};

/**
 * 新增点巡检工单
 * @param data
 */
export const addDmsBillsInspectInstance = (data: DmsBillsInspectInstanceForm) => {
  return request({
    url: '/dms/dmsBillsInspectInstance',
    method: 'post',
    data: data
  });
};

/**
 * 修改点巡检工单
 * @param data
 */
export const updateDmsBillsInspectInstance = (data: DmsBillsInspectInstanceForm) => {
  return request({
    url: '/dms/dmsBillsInspectInstance',
    method: 'put',
    data: data
  });
};

/**
 * 删除点巡检工单
 * @param inspectInstanceId
 */
export const delDmsBillsInspectInstance = (inspectInstanceId: string | number | Array<string | number>) => {
  return request({
    url: '/dms/dmsBillsInspectInstance/' + inspectInstanceId,
    method: 'delete'
  });
};


/**
 * 下拉框查询点巡检工单列表
 * @param query
 * @returns {*}
 */
export function getDmsBillsInspectInstanceList (query) {
    return request({
        url: '/dms/dmsBillsInspectInstance/getDmsBillsInspectInstanceList',
        method: 'get',
        params: query
    });
};
