import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { DmsPlanLubeVO, DmsPlanLubeForm, DmsPlanLubeQuery } from '@/api/dms/dmsPlanLube/types';

/**
 * 查询润滑计划列表
 * @param query
 * @returns {*}
 */

export const listDmsPlanLube = (query?: DmsPlanLubeQuery): AxiosPromise<DmsPlanLubeVO[]> => {
  return request({
    url: '/dms/dmsPlanLube/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询润滑计划详细
 * @param planLubeId
 */
export const getDmsPlanLube = (planLubeId: string | number): AxiosPromise<DmsPlanLubeVO> => {
  return request({
    url: '/dms/dmsPlanLube/' + planLubeId,
    method: 'get'
  });
};

/**
 * 新增润滑计划
 * @param data
 */
export const addDmsPlanLube = (data: DmsPlanLubeForm) => {
  return request({
    url: '/dms/dmsPlanLube',
    method: 'post',
    data: data
  });
};

/**
 * 修改润滑计划
 * @param data
 */
export const updateDmsPlanLube = (data: DmsPlanLubeForm) => {
  return request({
    url: '/dms/dmsPlanLube',
    method: 'put',
    data: data
  });
};

/**
 * 删除润滑计划
 * @param planLubeId
 */
export const delDmsPlanLube = (planLubeId: string | number | Array<string | number>) => {
  return request({
    url: '/dms/dmsPlanLube/' + planLubeId,
    method: 'delete'
  });
};


/**
 * 下拉框查询润滑计划列表
 * @param query
 * @returns {*}
 */
export function getDmsPlanLubeList (query) {
    return request({
        url: '/dms/dmsPlanLube/getDmsPlanLubeList',
        method: 'get',
        params: query
    });
};
